@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 12366 2020-06-19 06:41:16Z Andy $
+# $Id: Mailer.py 12380 2020-06-29 10:46:46Z Andy $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: Andy $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 12366 $
+# $Revision: 12380 $
 
 import os
 import re
@@ -154,8 +154,8 @@ class CloudMailer(Mailer):
         """
         super(CloudMailer, self).__init__(newsletter, test=test)
 
-        # If newsletter's SMTP server was cloud(default: id=1)
-        self.useCloud = True if self.newsletter.server.id == 1 else False
+        # If newsletter's SMTP server was cloud(default: port=1)
+        self.useCloud = True if self.newsletter.server.port == 1 else False
 
         self.pool = pool
 
