@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: TinyMCEWidget.py 11616 2019-06-07 02:15:46Z Andy $
+# $Id: TinyMCEWidget.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,10 +13,10 @@
 #
 # $Author: Andy $
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 11616 $
+# $Revision: 12366 $
 
 from django.utils.translation import ugettext as _
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.conf import settings
 
 from tinymce.widgets import TinyMCE
