@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 12366 2020-06-19 06:41:16Z Andy $
+# $Id: admin.py 12462 2020-08-17 09:10:43Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,14 +11,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2020-06-19 14:41:16 +0800 (週五, 19 六月 2020) $
-# $Revision: 12366 $
+# $Author: Lavender $
+# $Date: 2020-08-17 18:10:43 +0900 (週一, 17 八月 2020) $
+# $Revision: 12462 $
 
 from django.contrib import admin
 from django.contrib.admin.views.main import ChangeList
 from django.urls import reverse
 from django.utils.translation import ugettext as _
+from django.utils.safestring import mark_safe
 
 from emencia.django.newsletter.models import Newsletter
 
@@ -40,7 +41,7 @@ class AppChangeList(ChangeList):
 
     def get_queryset(self, request):
 
-        if self._user.is_authenticated() and self._user.is_staff:
+        if self._user.is_authenticated and self._user.is_staff:
             user = self._user
             queryset = super(AppChangeList, self).get_queryset(request)
             queryset = queryset.filter(user=user)
@@ -95,13 +96,13 @@ class AppAdmin(admin.ModelAdmin):
 
     def goEdit(self, obj):
         link = reverse('admin:integration_app_change', args=[obj.id])
-        return '<a href="%s">%s</a>' % (link, _('Edit'))
+        return mark_safe('<a href="%s">%s</a>' % (link, _('Edit')))
     goEdit.short_description = _('Edit')
     goEdit.allow_tags = True
 
     def goGroup(self, obj):
         link = reverse('admin:integration_group_changelist')
-        return '<a href="%s?app=%d">%s</a>' % (link, obj.id, obj.name)
+        return mark_safe('<a href="%s?app=%d">%s</a>' % (link, obj.id, obj.name))
     goGroup.short_description = _('Name')
     goGroup.allow_tags = True
 
@@ -199,7 +200,7 @@ class GroupAdmin(admin.ModelAdmin):
         Get last updated time by newsletters.
         """
         link = reverse('admin:newsletter_newsletter_changelist')
-        return '<a href="%s?group=%d">%s</a>' % (link, obj.id, obj.name)
+        return mark_safe('<a href="%s?group=%d">%s</a>' % (link, obj.id, obj.name))
     goNewsletter.short_description = _('name')
     goNewsletter.allow_tags = True
 
@@ -213,22 +214,22 @@ class GroupAdmin(admin.ModelAdmin):
     getLastUpdatedTime.allow_tags = True
 
     def displayHistory(self, obj):
-        return '<a href="%s">%s</a>' % (
+        return mark_safe('<a href="%s">%s</a>' % (
             reverse(
                 'Theophrastus.admin.integration.views.getGroupHistory', 
                 kwargs={'groupId': obj.id}
             ), _('View historic')
-        )
+        ))
     displayHistory.short_description = _('History')
     displayHistory.allow_tags = True
 
     def displayStatistics(self, obj):
-        return obj.getStatisticsLink()
+        return mark_safe(obj.getStatisticsLink())
     displayStatistics.short_description = _('Statistics')
     displayStatistics.allow_tags = True
 
     def displaySubscribers(self, obj):
-        return obj.getSubscriberLink()
+        return mark_safe(obj.getSubscriberLink())
     displaySubscribers.short_description = _('Subscribers')
     displaySubscribers.allow_tags = True
 
