@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11642 2019-06-24 02:28:05Z Andy $
+# $Id: models.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-24 10:28:05 +0800 (週一, 24 六月 2019) $
-# $Revision: 11642 $
+# $Date: 2020-06-19 15:41:16 +0900 (週五, 19 六月 2020) $
+# $Revision: 12366 $
 
 from django.db import models
 from django.contrib.auth.models import User
@@ -40,11 +40,11 @@ class Group(models.Model, BaseModelMixin):
                 return True
         return False
 
-    @models.permalink
+    # @models.permalink
     def statisticsUrl(self):
         return ('Theophrastus.integration.views.displayStatistics', (self.id,))
 
-    @models.permalink
+    # @models.permalink
     def subscriberUrl(self):
         return ('Theophrastus.integration.views.displaySubscribers', (self.id,))
 
@@ -78,7 +78,7 @@ class Group(models.Model, BaseModelMixin):
 
 class App(models.Model, BaseModelMixin):
     name = models.CharField(max_length=255, verbose_name=_('Name'))
-    user = models.ForeignKey(User, verbose_name=_('User'))
+    user = models.ForeignKey(User, verbose_name=_('User'), on_delete=models.CASCADE)
     groups = models.ManyToManyField(Group, related_name='groups')
     createdTime = models.DateTimeField(auto_now_add=True,
                                        verbose_name=_('Created time'))
@@ -100,7 +100,7 @@ class GroupMappingTable(models.Model, BaseModelMixin):
     )
 
     app = models.ForeignKey(
-        App, verbose_name=_('App'), help_text=_('Please choice a app.'))
+        App, verbose_name=_('App'), help_text=_('Please choice a app.'), on_delete=models.CASCADE)
 
     conditionType = models.IntegerField(
         choices=CONDITION_TYPES_CHOICES, default=0,
@@ -114,7 +114,7 @@ class GroupMappingTable(models.Model, BaseModelMixin):
         max_length=255, verbose_name=_('Group name'), blank=True, null=True)
 
     current = models.ForeignKey(Group, verbose_name=_('Current Group'),
-                                null=True)
+                                null=True, on_delete=models.CASCADE)
 
     def __unicode__(self):
         _to = self.current if self.current else self.group
