@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: api.py 9594 2016-03-18 12:59:58Z Judy $
+# $Id: api.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,19 +11,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-18 20:59:58 +0800 (週五, 18 三月 2016) $
-# $Revision: 9594 $
+# $Author: Andy $
+# $Date: 2019-06-07 11:15:46 +0900 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
-from django.conf.urls import url, patterns
+from django.conf.urls import url
 
 from Theophrastus.integration import views
 
-urlpatterns = patterns('',
+urlpatterns = [
 #    url(r'^user/exist/$', views.checkUserExist,
 #        name='Theophrastus.api.userExist'),
 
     url(r'^app/login/$', views.login, name='Theophrastus.api.login'),
     url(r'^app/mail/$', views.mail, name='Theophrastus.api.mail'),
-)
+]
 
