@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10850 2018-03-17 23:41:09Z David $
+# $Id: views.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,16 +11,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
+# $Author: Andy $
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10850 $
+# $Revision: 12366 $
 
 from django.shortcuts import render_to_response, get_object_or_404
 from django.utils.translation import ugettext_lazy as _
 from django.views.decorators.csrf import csrf_exempt
 from django.template import Template
 from django.template.loader import render_to_string
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.shortcuts import redirect
 from django.conf import settings
 from django.contrib.admin.views.decorators import staff_member_required
