@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10838 2018-03-12 10:54:45Z David $
+# $Id: admin.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,13 +11,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2018-03-12 18:54:45 +0800 (週一, 12 三月 2018) $
-# $Revision: 10838 $
+# $Author: Andy $
+# $Date: 2020-06-19 15:41:16 +0900 (週五, 19 六月 2020) $
+# $Revision: 12366 $
 
 from django.conf import settings
 from django.contrib import admin
 from django.utils.translation import ugettext as _
+from django.utils.html import format_html
 
 from emencia.django.newsletter.models import Newsletter
 
@@ -46,8 +47,8 @@ class NewsletterStatisticsAdmin(NewsletterTinyMCEAdmin):
         """Display link for statistics"""
         if (newsletter.status == Newsletter.SENDING or
             newsletter.status == Newsletter.SENT):
-            return '<a href="%s">%s</a>' % (
-                   newsletter.getStatisticsUrl(), _('View statistics'))
+            return format_html('<a href="%s">%s</a>' % (
+                   newsletter.getStatisticsUrl(), _('View statistics')))
         else:
             return _('Not available')
     statistics_link.allow_tags = True
@@ -59,8 +60,8 @@ class NewsletterStatisticsAdmin(NewsletterTinyMCEAdmin):
         """
         if (newsletter.status == Newsletter.SENDING or
             newsletter.status == Newsletter.SENT):
-            return '<a href="%s">%s</a>' % (
-                   newsletter.getSubscriberUrl(), _('View subscribers'))
+            return format_html('<a href="%s">%s</a>' % (
+                   newsletter.getSubscriberUrl(), _('View subscribers')))
         else:
             return _('Not available')
 
