@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11642 2019-06-24 02:28:05Z Andy $
+# $Id: models.py 12366 2020-06-19 06:41:16Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: Andy $
-# $Date: 2019-06-24 10:28:05 +0800 (週一, 24 六月 2019) $
-# $Revision: 11642 $
+# $Date: 2020-06-19 15:41:16 +0900 (週五, 19 六月 2020) $
+# $Revision: 12366 $
 
 from django.utils.translation import ugettext as _
+from django.urls import reverse
 
 from emencia.django.newsletter import models as emModels
 
@@ -23,13 +24,13 @@ import types
 
 from django.db import models
 
-@models.permalink
+# @models.permalink
 def getStatisticsUrl(self):
-    return ('Theophrastus.views.displayStatistics', (self.slug,))
+    return reverse('Theophrastus.views.displayStatistics', kwargs={'slug': self.slug})
 
-@models.permalink
+# @models.permalink
 def getSubscriberUrl(self):
-    return ('Theophrastus.views.displaySubscribers', (self.slug,))
+    return reverse('Theophrastus.views.displaySubscribers', kwargs={'slug': self.slug})
 
 emModels.Newsletter.getStatisticsUrl = getStatisticsUrl
 
