@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: subscribers.py 9594 2016-03-18 12:59:58Z Judy $
+# $Id: subscribers.py 11616 2019-06-07 02:15:46Z Andy $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,17 +11,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-18 20:59:58 +0800 (週五, 18 三月 2016) $
-# $Revision: 9594 $
+# $Author: Andy $
+# $Date: 2019-06-07 11:15:46 +0900 (週五, 07 六月 2019) $
+# $Revision: 11616 $
 
-from django.conf.urls import url, patterns
+from django.conf.urls import url
 
 from Theophrastus.statistics import views
 
-urlpatterns = patterns('',
+urlpatterns = [
     url(r'^display/(?P<slug>[-\w]+)/$', views.displaySubscribers,
         name='Theophrastus.views.displaySubscribers'),
     url(r'^charts/history/(?P<slug>[-\w]+)/$', views.getHistory,
         name='Theophrastus.statistics.ajax.getHistory'),
-)
+]
